# compiler-client

## Test

Within the root-folder of this repository, simple run:

```compiler-test .```


## Submit

Submissions are done by simply running:

```compiler-submit /path/to/your/repo```

or simply `compiler-submit .` from within the root folder of this repo.

You can define your own submisson tag via `--tag your_tag`, 
otherwise a random one will be generated.

If you define your own, please use a new tag for every new submission.
Every submission will create a new GitLab issue, where you can track the progress.